Mano was originally created by the `Harvard Neuroinformatics Research Group <https://www.neuroinfo.org>`_.

Contributors
````````````
- Timothy M. O'Keefe `@tokeefe <https://github.com/tokeefe>`_.
- Harris Hoke `@hhoke <https://github.com/hhoke>`_.
- Sarah (Sally) Guthrie `@sguthrie <https://github.com/sguthrie>`_.
